// Author: Torsten.Leitner@email.de
// (c) 2006/2007


#ifndef TWODEE_H_
#define TWODEE_H_

#include <stdio.h>
#include <iostream>
#include <iomanip>
#include <fstream>
#include <string>
#include <cstring>
#include <cstdlib>
#include <math.h>
#include <time.h>
#include <complex>
#include <vector>
#include <gsl/gsl_math.h>
//#include <gsl/gsl_complex.h>
//#include <gsl/gsl_complex_math.h>
//#include <gsl/gsl_sf_bessel.h>
#include <gsl/gsl_errno.h>
//#include <gsl/gsl_integration.h>
#include <gsl/gsl_const_mksa.h>
#include <gsl/gsl_fft_real.h>
//#include <gsl/gsl_fft_halfcomplex.h>
#include <gsl/gsl_fft_complex.h>

#include "Definitions.h"

#include "tools.h"
#include "gnuplot.h"




class twodee
{
public:
	twodee();
	twodee(double zdz, int zNr, double zdr);
	virtual ~twodee();


	void SetParameter(double zdz, int zNr, double zdr);
	
	int evolve(Complex *u, Complex *source, double omega, int steps);
	int evolve(vector<Complex > *field, Complex *source, double INomega, int steps);
	int evolve_onestep();
	
	int info();
	
	int show_plot(char *title, char *filename, int filenr);
	int show_plot(char *xlabel , char *ylabel, char *title, char *style ,char *filename, int filenr, 
					  int logscale, int terminaltype, double delay);
	
	
//Variables
	Complex *u;
	//vector<Complex > *u;
	double *r;
	double omega;
	int Nz,Nr;
	
private:
//Variables
	Complex *alpha,*beta,*gamma,*b;
	Complex prefactor; // prefactor of the (d/dz)-Term
	double dr; //h=Delta(r)=r[j]-r[j-1]
	double dz; //z-step
	
};

#endif /*TWODEE_H_*/
