
// Author: Torsten.Leitner@email.de
// (c) 2006/2007




#include "GasTargetIonization.h"
#include <sstream>

using namespace std;

// cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
int Elementwise_Exp_minus_X(double **X, int Nr, int Ntw)
{
	for (int ir=0;ir<Nr;ir++)	{
		for (int jt=1;jt<Ntw;jt++)	{
			X[ir][jt] = exp(-X[ir][jt]);
		}
	}
	return 0;
}
int Elementwise_Exp_minus_X(Complex **X, int Nr, int Ntw)
{
	for (int ir=0;ir<Nr;ir++)	{
		for (int jt=1;jt<Ntw;jt++)	{ 
			X[ir][jt] = exp(-X[ir][jt]);
		}
	}
	return 0;
}
// cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

// *********************************************************************************************************************
// *********************************************************************************************************************

double TIR_fit_Ne(const double x)
{
	// 
	//   Input: x = E[au] --- Out: tir(E) [a.u.] 

	double tir=-1;
	
// from GNUPLOT:

//FIT:    data read from "Ne.rate" u ($1):(exp($2))
//        #datapoints = 87
//        residuals are weighted equally (unit weight)
//
//function used for fitting: p(x)
//final sum of squares of residuals : 1.74806e-07
//
//degrees of freedom (ndf) : 79
//rms of residuals      (stdfit) = sqrt(WSSR/ndf)      : 4.70398e-05
//variance of residuals (reduced chisquare) = WSSR/ndf : 2.21274e-09
//
//Final set of parameters            Asymptotic Standard Error
//=======================            ==========================
double
p0              = -0.0196845 ,//      +/- 0.00116      (5.891%)
p1              = 0.690106   ,//      +/- 0.04055      (5.876%)
p2              = -8.77527   ,//      +/- 0.5624       (6.408%)
p3              = 49.1145    ,//      +/- 4.04         (8.225%)
p4              = -118.746   ,//      +/- 16.36        (13.78%)
p5              = 132.173    ,//      +/- 37.64        (28.48%)
p6              = -41.9565   ,//      +/- 45.85        (109.3%)
p7              = -19.507    ;//      +/- 22.95        (117.7%)
//
//Function:  p(x) = p7*x**7+p6*x**6+p5*x**5 + p4*x**4 + p3*x**3 +p2*x**2+p1*x**1+p0
//		= Sum[0:7] ( p_i * x**i )
//
//
//
//correlation matrix of the fit parameters:
//
//               p0     p1     p2     p3     p4     p5     p6     p7     
//p0              1.000 
//p1             -0.996  1.000 
//p2              0.984 -0.996  1.000 
//p3             -0.968  0.986 -0.997  1.000 
//p4              0.949 -0.973  0.989 -0.997  1.000 
//p5             -0.928  0.956 -0.977  0.991 -0.998  1.000 
//p6              0.907 -0.938  0.963 -0.981  0.992 -0.998  1.000 
//p7             -0.886  0.920 -0.948  0.969 -0.984  0.994 -0.999  1.000 

	tir = p7*pow(x,7) + p6*pow(x,6) +p5*pow(x,5)+p4*pow(x,4)+p3*pow(x,3) + p2*pow(x,2) +p1*pow(x,1)+p0;	
	
	if (tir<0){tir=0;}  // tir<0 gibts nich... tir=0 stattdessen is nur bedingt OK
//	else { tir = tir / time_AUtoSI ;  } // Ausgabe der Rate wieder in SI-Einheiten ...
				// 1/sec  = (1/(time_SItoAU)) au    = time_AUtoSI au
				// 1 au   = (1/time_AUtoSI) (1/sec) = time_SItoAU (1/sec)
	
	//cout << tir << endl;
	
	return tir;
}

// *********************************************************************************************************************

double TIR_fit_He(const double x)
{
	// 
	//   Input: x = E[au] --- Out: tir(E) [a.u.] 

    double tir=-1;
 

// from GNUPLOT:

//FIT:    data read from "He.rate" u ($1):(exp($2))
//        #datapoints = 60
//        residuals are weighted equally (unit weight)
//
//function used for fitting: p(x)
    
//final sum of squares of residuals : 5.50913e-06
//rel. change during last iteration : -2.16758e-12
//
//degrees of freedom (ndf) : 49
//rms of residuals      (stdfit) = sqrt(WSSR/ndf)      : 0.000335308
//variance of residuals (reduced chisquare) = WSSR/ndf : 1.12431e-07
//
//Final set of parameters            Asymptotic Standard Error
//=======================            ==========================
double
p0              = -0.0334551,//       +/- 0.003419     (10.22%)
p1              = 1.01906   ,//       +/- 0.08581      (8.42%)
p2              = -11.5231  ,//       +/- 0.8443       (7.327%)
p3              = 61.6111   ,//       +/- 4.36         (7.076%)
p4              = -173.033  ,//       +/- 13.28        (7.676%)
p5              = 308.361   ,//       +/- 25.29        (8.2%)
p6              = -360.666  ,//       +/- 30.84        (8.55%)
p7              = 274.664   ,//       +/- 24.04        (8.753%)
p8              = -130.669  ,//       +/- 11.57        (8.854%)
p9              = 35.1651   ,//       +/- 3.127        (8.893%)
p10             = -4.07854  ;//       +/- 0.3628       (8.896%)

//
//Function:  p(x) = p10*x**10+p9*x**9+p8*x**8+p7*x**7+p6*x**6+p5*x**5 + p4*x**4 + p3*x**3 +p2*x**2+p1*x**1+p0
//		= Sum[0:10] ( p_i * x**i )
//
//
//correlation matrix of the fit parameters:
//
//               p0     p1     p2     p3     p4     p5     p6     p7     p8     p9     p10    
//p0              1.000 
//p1             -0.991  1.000 
//p2              0.971 -0.993  1.000 
//p3             -0.944  0.977 -0.995  1.000 
//p4              0.915 -0.956  0.983 -0.996  1.000 
//p5             -0.887  0.933 -0.966  0.987 -0.997  1.000 
//p6              0.859 -0.910  0.948 -0.974  0.990 -0.998  1.000 
//p7             -0.834  0.887 -0.930  0.960 -0.980  0.992 -0.998  1.000 
//p8              0.810 -0.866  0.911 -0.945  0.969 -0.984  0.994 -0.999  1.000 
//p9             -0.789  0.846 -0.893  0.930 -0.957  0.975 -0.988  0.995 -0.999  1.000 
//p10             0.769 -0.827  0.876 -0.915  0.944 -0.966  0.980 -0.990  0.996 -0.999  1.000 
//    
    tir = p10*pow(x,10)+p9*pow(x,9)+p8*pow(x,8)+p7*pow(x,7)
         + p6*pow(x,6) +p5*pow(x,5)+p4*pow(x,4)+p3*pow(x,3)
         + p2*pow(x,2) +p1*pow(x,1)+p0;	

	if (tir<0){tir=0;}  // tir<0 gibts nich... tir=0 stattdessen is nur bedingt OK
//	else { tir = tir / time_AUtoSI ;  } // Ausgabe der Rate wieder in SI-Einheiten ...
				// 1/sec  = (1/(time_SItoAU)) au    = time_AUtoSI au
				// 1 au   = (1/time_AUtoSI) (1/sec) = time_SItoAU (1/sec)
	
	//cout << tir << endl;
	
	return tir;
}
// *********************************************************************************************************************
// *********************************************************************************************************************





// *********************************************************************************************************************
// *********************************************************************************************************************

double TIR_ADK(const double E_in, const double Ip, const int Z)
{
	double tir=-1e100; // Initial Value is very unphysical ... helps to determine errors in evaluation of the function ...
	char LOGmessage[80];
	
	
/// Ip in [eV] !!!

	/// w(t) = \omega_p |C_{n^*}|^2 (\frac{4\omega_p}{\omega_t})^(2n^{*}-1)\exp(-\frac{4\omega_p}{3\omega_t})
	/// \omega_p = \frac{I_p}{\hbar} ~~~~~ \n^* = Z \sqrt{\frac{I_{ph}}{I_p}}
	/// \omega_t = \frac{e|E_{1}(t)|}{\sqrt{2 m_e I_p}}
	/// |C_{n^*}|^2 = \frac{2^{2n^*}}{n^* \Gamma(n^* +1)\Gamma(n^*)}	
	///
	/// w(t) = A (\frac{B}{|E_{1}(t)|})^(2n^{*}-1)\exp(-\frac{B}{3|E_{1}(t)|})
	///
	///  A = \frac{\frac{2^{2n^*}}}{\hbar n^* \Gamma(n^* +1)\Gamma(n^*)} (\frac{I_p}{[eV]}) [1/s]	
	///  B = TIR_ADK_CONSTANT_B  (\frac{I_p}{[eV]})^(3/2}
	///      TIR_ADK_CONSTANT_B  =  2.04926724e10 ~~[\frac{V}{m (ev)^{3/2}})]
	///
	
	double nstar        =  Z*sqrt(IP_HYDROGEN/Ip); //both in [eV]
	double mstar	    =  2*nstar - 1; // helper variable ...
	double wp           =  Ip/HBAR_EVOLT;
	double Cnstarsquare =  pow(2,2*nstar) / ( nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
//	double A            =  Ip * pow(2,2*nstar) / (HBAR_EVOLT * nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
//      double B 	    =  TIR_ADK_CONSTANT_B * sqrt(Ip*Ip*Ip);
    
//    double x,y;
	

	double E;  
// 		E = E_in / VperM_SItoAU;  // E: au 2 SI
// 		E = E_in * VperM_SItoAU;  // E: SI 2 au
 		E = E_in;  			   // E: sth2sth
 		
	double wt = E * ECHARGE / sqrt( 2 * EMASS * (ECHARGE*Ip) );
	

	if (E < LASER_EQUAL_ZERO) {	tir = 0 ;  }
	else if (isnan(E)) 
		{
				// Laser -> Inf ... General error ... maybe FieldOverRun ...
				sprintf(LOGmessage,"Laser is NaN !!! --- E = %g",E);log::file(LOGmessage);
				cout << LOGmessage << endl;
				tir = 0 ;  
	  	}  
  	else {  // everything is normal ...	
//				x    = B / y;
//	 			tir = A * pow(x,mstar) * exp( -x/3 );
//				tir = A * exp( mstar * log(x) - x/3 ) ;
//		tir = wp * Cnstarsquare * pow( 4*wp / wt , mstar ) * exp(-4*wp / (3*wt) );
		tir = wp * Cnstarsquare * exp( mstar*log(4*wp/wt) - (4*wp/(3*wt)) );
	} 
	
	if ( tir < 0 ) { sprintf(LOGmessage,"tir = %g < 0 !!! --- E = %g",tir,E);log::both(LOGmessage);  }
	
	return tir;
}

// *********************************************************************************************************************
// *********************************************************************************************************************

///*  //  in reasonable units with natures constants and so ... Ip in [eV] 
// cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
int Integral_TIR_AmmosovDeloneKrainov(double **IntTir, class tArrayComplex2D_rt 	*Laser,  double Ip, int Z)
{	/// TunnelIonisationRate(r,t) -> tir(r,t)
	/// This function calculates  \text{IntTir}(r,t) =  -\int_0^t  tir(r,t')dt'  


//ofstream TIRout;
//TIRout.open("TIRout.log", ios::out|ios::trunc);
//TIRout.close();

//logbuch::message("Hallo Int_TIR_ADK");
//logbuch::logfile("Hallo Int_TIR_ADK");

//*

	/// Ip in [eV] !!!

	/// w(t) = \omega_p |C_{n^*}|^2 (\frac{4\omega_p}{\omega_t})^(2n^{*}-1)\exp(-\frac{4\omega_p}{3\omega_t})
	/// \omega_p = \frac{I_p}{\hbar} ~~~~~ \n^* = Z \sqrt{\frac{I_{ph}}{I_p}}
	/// \omega_t = \frac{e|E_{1}(t)|}{\sqrt{2 m_e I_p}}
	/// |C_{n^*}|^2 = \frac{2^{2n^*}}{n^* \Gamma(n^* +1)\Gamma(n^*)}	
	///
	/// w(t) = A (\frac{B}{|E_{1}(t)|})^(2n^{*}-1)\exp(-\frac{B}{3|E_{1}(t)|})
	///
	///  A = \frac{\frac{2^{2n^*}}}{\hbar n^* \Gamma(n^* +1)\Gamma(n^*)} (\frac{I_p}{[eV]}) [1/s]	
	///  B = TIR_ADK_CONSTANT_B  (\frac{I_p}{[eV]})^(3/2}
	///      TIR_ADK_CONSTANT_B  =  2.04926724e10 ~~[\frac{V}{m (ev)^{3/2}})]
	///

	char LOGmessage[80];

	double nstar        =  Z*sqrt(IP_HYDROGEN/Ip);
	double mstar	    =  2*nstar - 1; // helper variable ...
//	double wp           =  Ip/HBAR_EVOLT;
//	double Cnstarsquare =  pow(2,2*nstar) / ( nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
	double A            =  Ip * pow(2,2*nstar) / (HBAR_EVOLT * nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
        double B 	    =  TIR_ADK_CONSTANT_B * sqrt(Ip*Ip*Ip); 
		// Enumerator B of the later argument x = B / abs[Laser->data(t)];
//cout << B << endl;
	// bis hier sinds konsts, die nachher im objekt nur bei init belegt werden muessen ...

	int ir=0,jt=0;
	double tir1=0,tir2=0;
	double x=0 , y=0;
// This loop calculates the integral IntTir(r,t)
	for (ir=0;ir<Laser->Nr;ir++) 
	{
			jt=0;
			y    = abs( Laser->data[ir][jt] ) ;

			if (y < LASER_EQUAL_ZERO) { 
				// x = B/y = BIG; -->
//	sprintf(LOGmessage,"Laser is SMALL at ir = % 4i , jt = % 4i , Laser  = % 4.12e",ir,jt,y);log::file(LOGmessage);
				tir2 = 0 ;  
			  }
			else if (isnan(y)) {
				// Laser -> Inf ... General error ... maybe FieldOverRun ...
				sprintf(LOGmessage,"Laser is NaN at ir = % 4i , jt = % 4i , Laser  = % 4.12e",ir,jt,y);log::file(LOGmessage);
				cout << LOGmessage << endl;
				tir2 = 0 ;  
			  }  
  		    else {  // everything is normal ...	
				x    = B / y;
	//			tir2 = A * pow(x,mstar) * exp( -x/3 );
				tir2 = A * exp( mstar * log(x) - x/3 ) ;
			}
//// ************************************************************************************************
			if (isnan(tir2) ) 
			{
		//	%[flags][width][.precision][length]specifier  --- eg.: %03.3hi
			sprintf(LOGmessage,"TIR is NaN at ir = % 4i , jt = % 4i , Laser  = % 4.12e",ir,jt,y);log::file(LOGmessage);		
			cout << LOGmessage << endl;
			tir2=0;
			}
//// ************************************************************************************************
		// Naive: Int(tmin) = f(tmin)
		IntTir[ir][0]=tir2; 
//cout << ir << " " << 0 << " " << IntTir[ir][0] <<endl;
		for (jt=1;jt<Laser->Ntw;jt++)
		{ // naive integration ... int = sum( 0.5*dt*(tir1+tir2) ) = sum ( trapezes )
			y    = abs( Laser->data[ir][jt] ) ;

			if (y < LASER_EQUAL_ZERO) { 
				// x = B/y = BIG; -->
	//	sprintf(LOGmessage,"Laser is SMALL at ir = % 4i , jt = % 4i , Laser  = % 4.12e",ir,jt,y);log::file(LOGmessage);
				tir2 = 0 ;  
			  }
			else if (isnan(y)) {
				// Laser -> Inf ... General error ... maybe FieldOverRun ...
				sprintf(LOGmessage,"Laser is NaN at ir = % 4i , jt = % 4i , Laser  = % 4.12e",ir,jt,y);log::file(LOGmessage);
				cout << LOGmessage << endl;
				tir2 = 0 ;  
			  }  
  		    else {  // everything is normal ...	
				x    = B / y;
	//			tir2 = A * pow(x,mstar) * exp( -x/3 );
				tir2 = A * exp( mstar * log(x) - x/3 ) ;
			}
//// ************************************************************************************************
			if (isnan(tir2) ) 
			{
		//	%[flags][width][.precision][length]specifier  --- eg.: %03.3hi
			sprintf(LOGmessage,"TIR is NaN at ir = % 4i , jt = % 4i , Laser  = % 4.12e",ir,jt,y);log::file(LOGmessage);		
			cout << LOGmessage << endl;
			tir2=0;
			}
//// ************************************************************************************************
			IntTir[ir][jt] = IntTir[ir][jt-1] + 0.5*(tir1+tir2)*(Laser->dt);
//cout << ir << " " << jt << " " << IntTir[ir][jt] <<endl;			
		} 
	}
// cin >> blub;

// */

	return 0;
}
// ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
//*/
///*  //  in reasonable units with natures constants and so ... Ip in [eV] 
// cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
int Integral_TIR_AmmosovDeloneKrainov(double **IntTir, Complex **E, double dt,int Nr, int Ntw, double Ip, int Z)
{	/// TunnelIonisationRate(r,t) -> tir(r,t)
	/// Lewenstein's natural Units: hbar=me=e=c=w0=1
	/// This function calculates  \text{IntTir}(r,t) = \exp( -\int_0^t  tir(r,t')dt'  )
	
	/// Ip in [eV] !!!
	
// char blub[80]; 

	     double nstar       =  Z*sqrt(IP_HYDROGEN/Ip);
	long double mstar		=  2*nstar - 1; // helper variable ...
//	double wp           =  Ip/HBAR_EVOLT;
//	double Cnstarsquare =  pow(2,2*nstar) / ( nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
	double A            =  Ip * pow(2,2*nstar) / (HBAR_EVOLT * nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
			// A = wp * |Cnstar|^2;  

    double  B = TIR_ARGUMENT_CONSTANT * Ip*Ip*Ip; // Enumerator B of the later argument x = B / abs[E(t)];

	// bis hier sinds konsts, die nachher im objekt nur bei init belegt werden muessen ...
	int ir,jt;
	double tir1=0,tir2=0;
	long double x=0;
// This loop calculates the integral IntTir(r,t)
	for (ir=0;ir<Nr;ir++) 
	{
		
		x    = B / abs( E[ir][0] ) ;
		
//		tir2 = A * pow(x,mstar) * exp( -x/3 );
		tir2 = A * double( exp( mstar * log(x) - x/3 ) );   // x,mstar are long double
		
		// wt    =  ECHARGE * abs( E[ir][0] ) / sqrt( 2 * Ip * EVOLT * EMASS );
		// all the constants in this formula are held in "wtPrefactor"
//		wt	 =	wtPrefactor * abs( E[ir][0] ) ; // wt= e*|E(t)| / sqrt(2*m_e*I_p)
//cout <<"wt "<< wt << endl; //cin >> blub;

//		tir2 =  wp*Cnstarsquare * pow( (4*wp/wt),(2*nstar -1) ) * exp( -4*wp/(3*wt) );

//cout <<"E0 " << abs( E[ir][0] ) << endl;
//cout <<"tir2 "<< tir2 << endl; //cin >> blub;

		// Naive: Int(tmin) = f(tmin)
		IntTir[ir][0]=tir2; 
//cout << ir << " " << 0 << " " << IntTir[ir][0] <<endl;
		for (jt=1;jt<Ntw;jt++)
		{ // naive integration ... int = sum( 0.5*dt*(tir1+tir2) ) = sum ( trapezes )
//			wt	= wtPrefactor * abs( E[ir][jt] )  / sqrt(2*Ip);
//			tir1=tir2;			// wt= e*|E(t)| / sqrt( 2*m_e*(e/[C])*(I_p/[eV]) ) = sqrt(e)*.....
//			tir2 =wp*Cnstarsquare * pow( (4*wp/wt),(2*nstar -1) ) * exp( -4*wp/(3*wt) );
			
			x    = B / abs( E[ir][jt] ) ;
		    tir1 = tir2;
		    
//			tir2 = A * pow(x,mstar) * exp( -x/3 );
			tir2 = A * double( exp( mstar * log(x) - x/3 ) );   // x,mstar are long double
			IntTir[ir][jt] = IntTir[ir][jt-1] + 0.5*(tir1+tir2)*dt;
//cout << ir << " " << jt << " " << IntTir[ir][jt] <<endl;			
		} 
	}
// cin >> blub;
	return 0;
}
// ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
//*/


/*  //  in Lewenstein-Units ... maybe wrong
// cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
int CalcIntTir(double **IntTir, Complex **E, double dt,int Nr, int Ntw, double Ip, double Z)
{	/// TunnelIonisationRate(r,t) -> tir(r,t)
	/// Lewenstein's natural Units: hbar=me=e=c=w0=1
	/// This function calculates  \text{IntTir}(r,t) = \exp( -\int_0^t  tir(r,t')dt'  )
	double wp,nstar,Cnstarsquare,wt,tir1,tir2;
	wp           =	Ip;	// Ip/(hbar==1)
	nstar        = 	Z*sqrt(IP_HYDROGEN/Ip);
	Cnstarsquare =	pow(2,2*nstar) / ( nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
	// bis hier sinds konsts, die nachher im objekt nur bei init belegt werden muessen ...
//TunnelIonisationRate(IntTir,E,Nr,Ntw,Ip,Z);
	int ir,jt;
//tir =wp*Cnstarsquare * pow( (4*wp/wt),(2*nstar -1) ) * exp( -4*wp/(3*wt) );

// This loop calculates the integral IntTir(r,t)
	for (ir=0;ir<Nr;ir++) 
	{
		wt	 =	abs( E[ir][0] ) / sqrt(2*Ip); // wt= e*|E(t)| / sqrt(2*m_e*I_p)
		tir2 =  wp*Cnstarsquare * pow( (4*wp/wt),(2*nstar -1) ) * exp( -4*wp/(3*wt) );
		// Naive: Int(tmin) = f(tmin)
		IntTir[ir][0]=tir2; 
		for (jt=1;jt<Ntw;jt++)
		{ // naive integration ... int = sum( 0.5*dt*(tir1+tir2) ) = sum ( trapezes )
			wt	=	abs( E[ir][jt] )  / sqrt(2*Ip); // wt= e*|E(t)| / sqrt(2*m_e*I_p)
			tir1=tir2;
			tir2 =wp*Cnstarsquare * pow( (4*wp/wt),(2*nstar -1) ) * exp( -4*wp/(3*wt) );
			IntTir[ir][jt] = IntTir[ir][jt-1] + 0.5*(tir1+tir2)*dt;			
		} 
	}
// This loop calculates the exp(-integral) -> IntTir(r,t) = exp( -int_0^t { tir(t')dt' } )
	for (ir=0;ir<Nr;ir++)	{
		for (jt=1;jt<Ntw;jt++)	{
			IntTir[ir][jt] = exp(-IntTir[ir][jt]);
		}
	}
	return 0;
}
// ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
//*/


/*
// ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
inline int TunnelIonisationRate(double **tir, Complex **E, int Nr, int Ntw, double Ip, double Z)
{	// TunnelIonisationRate(t) -> tir(t)
	// Lewenstein's natural Units: hbar=me=e=c=w0=1
	int ir,jt;
	double wp,nstar,Cnstarsquare,wt;
	wp           =	Ip;	// Ip/(hbar==1)
	nstar        = 	Z*sqrt(IP_HYDROGEN/Ip);
	Cnstarsquare =	pow(2,2*nstar) / ( nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
	// bis hier sinds konsts, die nachher im objekt nur bei init belegt werden muessen ...
	
	for (ir=0;ir<Nr;ir++) {  for (jt=0;jt<Ntw;jt++) { 
				wt	=	abs( E[ir][jt] )  / sqrt(2*Ip); // wt= e*|E(t)| / sqrt(2*m_e*I_p)
		tir[ir][jt] =   wp * Cnstarsquare * pow( (4*wp/wt),(2*nstar -1) ) * exp( -4*wp/(3*wt) );
	}  }
	return 0;
}
// ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
//*/

/*  //  in reasonable units with natures constants and so ... Ip in [eV] 
// cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
int TIR_AmmosovDeloneKrainov(double **IntTir, class tArrayComplex2D_rt 	*Laser, double dt,int Nr, int Ntw, double Ip, int Z)
{	/// TunnelIonisationRate(r,t) -> tir(r,t)
	/// Lewenstein's natural Units: hbar=me=e=c=w0=1
	/// This function calculates  \text{IntTir}(r,t) = \exp( -\int_0^t  tir(r,t')dt'  )
	
	/// Ip in [eV] !!!
	
// char blub[80]; 

	     double nstar       =  Z*sqrt(IP_HYDROGEN/Ip);
	long double mstar		=  2*nstar - 1; // helper variable ...
//	double wp           =  Ip/HBAR_EVOLT;
//	double Cnstarsquare =  pow(2,2*nstar) / ( nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
	double A            =  Ip * pow(2,2*nstar) / (HBAR_EVOLT * nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
			// A = wp * |Cnstar|^2;  

    double  B = TIR_ARGUMENT_CONSTANT * Ip*Ip*Ip; // Enumerator B of the later argument x = B / abs[Laser->data(t)];

	// bis hier sinds konsts, die nachher im objekt nur bei init belegt werden muessen ...
	int ir,jt;
	double tir1=0,tir2=0;
	long double x=0;
// This loop calculates the integral IntTir(r,t)
	for (ir=0;ir<Nr;ir++) 
	{
		
		x    = B / abs( Laser->data[ir][0] ) ;
		
//		tir2 = A * pow(x,mstar) * exp( -x/3 );
		tir2 = A * double( exp( mstar * log(x) - x/3 ) );   // x,mstar are long double
		
		// wt    =  ECHARGE * abs( Laser->data[ir][0] ) / sqrt( 2 * Ip * EVOLT * EMASS );
		// all the constants in this formula are held in "wtPrefactor"
//		wt	 =	wtPrefactor * abs( Laser->data[ir][0] ) ; // wt= e*|E(t)| / sqrt(2*m_e*I_p)
//cout <<"wt "<< wt << endl; //cin >> blub;

//		tir2 =  wp*Cnstarsquare * pow( (4*wp/wt),(2*nstar -1) ) * exp( -4*wp/(3*wt) );

//cout <<"E0 " << abs( Laser->data[ir][0] ) << endl;
//cout <<"tir2 "<< tir2 << endl; //cin >> blub;

		// Naive: Int(tmin) = f(tmin)
		IntTir[ir][0]=tir2; 
//cout << ir << " " << 0 << " " << IntTir[ir][0] <<endl;
		for (jt=1;jt<Ntw;jt++)
		{ // naive integration ... int = sum( 0.5*dt*(tir1+tir2) ) = sum ( trapezes )
//			wt	= wtPrefactor * abs( Laser->data[ir][jt] )  / sqrt(2*Ip);
//			tir1=tir2;			// wt= e*|E(t)| / sqrt( 2*m_e*(e/[C])*(I_p/[eV]) ) = sqrt(e)*.....
//			tir2 =wp*Cnstarsquare * pow( (4*wp/wt),(2*nstar -1) ) * exp( -4*wp/(3*wt) );
			
			x    = B / abs( Laser->data[ir][jt] ) ;
		    tir1 = tir2;
		    
//			tir2 = A * pow(x,mstar) * exp( -x/3 );
			tir2 = A * double( exp( mstar * log(x) - x/3 ) );   // x,mstar are long double
			IntTir[ir][jt] = IntTir[ir][jt-1] + 0.5*(tir1+tir2)*dt;
//cout << ir << " " << jt << " " << IntTir[ir][jt] <<endl;			
		} 
	}
// This loop calculates the exp(-integral) -> IntTir(r,t) = exp( -int_0^t { tir(t')dt' } )
	for (ir=0;ir<Nr;ir++)	{
		for (jt=1;jt<Ntw;jt++)	{
			IntTir[ir][jt] = exp(-IntTir[ir][jt]);
		}
	}
// cout << 0 << " " << 8 << " " << IntTir[0][8] <<endl;
// cin >> blub;
	return 0;
}
// ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
//*/
   

/*
// *********************************************************************************************************************
// *********************************************************************************************************************

double TIR_ADK(const double E, const double Ip, const int Z)
{
	double tir=-1e100; // Initial Value is very unphysical ... helps to determine errors in evaluation of the function ...
	char LOGmessage[80];
	
	
/// Ip in [eV] !!!

	/// w(t) = \omega_p |C_{n^*}|^2 (\frac{4\omega_p}{\omega_t})^(2n^{*}-1)\exp(-\frac{4\omega_p}{3\omega_t})
	/// \omega_p = \frac{I_p}{\hbar} ~~~~~ \n^* = Z \sqrt{\frac{I_{ph}}{I_p}}
	/// \omega_t = \frac{e|E_{1}(t)|}{\sqrt{2 m_e I_p}}
	/// |C_{n^*}|^2 = \frac{2^{2n^*}}{n^* \Gamma(n^* +1)\Gamma(n^*)}	
	///
	/// w(t) = A (\frac{B}{|E_{1}(t)|})^(2n^{*}-1)\exp(-\frac{B}{3|E_{1}(t)|})
	///
	///  A = \frac{\frac{2^{2n^*}}}{\hbar n^* \Gamma(n^* +1)\Gamma(n^*)} (\frac{I_p}{[eV]}) [1/s]	
	///  B = TIR_ADK_CONSTANT_B  (\frac{I_p}{[eV]})^(3/2}
	///      TIR_ADK_CONSTANT_B  =  2.04926724e10 ~~[\frac{V}{m (ev)^{3/2}})]
	///
	
	double nstar        =  Z*sqrt(IP_HYDROGEN/Ip); //both in [eV]
	double mstar	    =  2*nstar - 1; // helper variable ...
//	double wp           =  Ip/HBAR_EVOLT;
//	double Cnstarsquare =  pow(2,2*nstar) / ( nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
	double A            =  Ip * pow(2,2*nstar) / (HBAR_EVOLT * nstar*gsl_sf_gamma(nstar+1)*gsl_sf_gamma(nstar) ) ;
    double B 	    	=  TIR_ADK_CONSTANT_B * sqrt(Ip*Ip*Ip);
    
    double x,y;
    
 		y = E / VperM_SItoAU;  // E: au 2 SI
// 		y = E * VperM_SItoAU;  // E: SI 2 au
// 		y = E;  			   // E: sth2sth
 		
	

	if (y < LASER_EQUAL_ZERO) {	tir = 0 ;  }
	else if (isnan(y)) 
		{
				// Laser -> Inf ... General error ... maybe FieldOverRun ...
				sprintf(LOGmessage,"Laser is NaN !!! --- E = %g",y);log::file(LOGmessage);
				cout << LOGmessage << endl;
				tir = 0 ;  
	  	}  
  	else {  // everything is normal ...	
				x    = B / y;
//	 			tir = A * pow(x,mstar) * exp( -x/3 );
				tir = A * exp( mstar * log(x) - x/3 ) ;
	} 
	
	if ( tir < 0 ) { sprintf(LOGmessage,"tir = %g < 0 !!! --- E = %g",tir,y);log::both(LOGmessage);  }
	
	return tir;
}

// *********************************************************************************************************************
// *********************************************************************************************************************

/*////

